aboutsummaryrefslogtreecommitdiffstats
path: root/local-configure.patch
diff options
context:
space:
mode:
Diffstat (limited to 'local-configure.patch')
-rw-r--r--local-configure.patch67
1 files changed, 51 insertions, 16 deletions
diff --git a/local-configure.patch b/local-configure.patch
index b3444fe..25bb3c4 100644
--- a/local-configure.patch
+++ b/local-configure.patch
@@ -1,57 +1,92 @@
diff --git a/lib/curl_config.h b/lib/curl_config.h
-index d3d74dc..526bcf7 100644
+index 273593ba6..6ba8faca3 100644
--- a/lib/curl_config.h
+++ b/lib/curl_config.h
@@ -128,7 +128,10 @@
#define HAVE_BORINGSSL 1
/* Define to 1 if you have the clock_gettime function and monotonic timer. */
-+#ifndef __APPLE__
++#if !defined(__APPLE__)
+/* CLOCK_MONOTONIC is not defined in mac when building for the host. */
#define HAVE_CLOCK_GETTIME_MONOTONIC 1
+#endif
/* Define to 1 if you have the closesocket function. */
/* #undef HAVE_CLOSESOCKET */
-@@ -442,10 +445,14 @@
+@@ -430,10 +433,14 @@
#define HAVE_MEMORY_H 1
/* Define to 1 if you have the memrchr function or macro. */
-+#ifndef __APPLE__
++#if !defined(__APPLE__)
#define HAVE_MEMRCHR 1
+#endif
/* Define to 1 if you have the MSG_NOSIGNAL flag. */
-+#ifndef __APPLE__
++#if !defined(__APPLE__)
#define HAVE_MSG_NOSIGNAL 1
+#endif
/* Define to 1 if you have the <netdb.h> header file. */
#define HAVE_NETDB_H 1
-@@ -858,7 +865,7 @@
+@@ -787,9 +794,6 @@
+ /* Define absolute filename for winbind's ntlm_auth helper. */
+ /* #undef NTLM_WB_FILE */
+
+-/* cpu-machine-OS */
+-#define OS "arm-unknown-linux-androideabi"
+-
+ /* Name of package */
+ #define PACKAGE "curl"
+
+@@ -827,7 +831,7 @@
+ #define RECV_TYPE_ARG4 int
+
+ /* Define to the function return type for recv. */
+-#define RECV_TYPE_RETV int
++#define RECV_TYPE_RETV ssize_t
+
+ /* Define as the return type of signal handlers (`int' or `void'). */
#define RETSIGTYPE void
+@@ -845,7 +849,7 @@
+ #define SELECT_TYPE_ARG5 struct timeval *
+
+ /* Define to the function return type for select. */
+-#define SELECT_TYPE_RETV int
++#define SELECT_TYPE_RETV ssize_t
- /* Define to the type qualifier of arg 5 for select. */
--#define SELECT_QUAL_ARG5
-+#define SELECT_QUAL_ARG5
+ /* Define to the type qualifier of arg 2 for send. */
+ #define SEND_QUAL_ARG2 const
+@@ -863,32 +867,14 @@
+ #define SEND_TYPE_ARG4 int
- /* Define to the type of arg 1 for select. */
- #define SELECT_TYPE_ARG1 int
-@@ -890,18 +897,9 @@
/* Define to the function return type for send. */
- #define SEND_TYPE_RETV int
+-#define SEND_TYPE_RETV int
++#define SEND_TYPE_RETV ssize_t
+
+ /* The size of `int', as computed by sizeof. */
+ #define SIZEOF_INT 4
-/* The size of `long', as computed by sizeof. */
-#define SIZEOF_LONG 4
-
- /* The size of `long long', as computed by sizeof. */
- /* #undef SIZEOF_LONG_LONG */
-
+-/* The size of `long long', as computed by sizeof. */
+-/* #undef SIZEOF_LONG_LONG */
+-
-/* The size of `off_t', as computed by sizeof. */
-#define SIZEOF_OFF_T 8
-
+ /* The size of `short', as computed by sizeof. */
+ #define SIZEOF_SHORT 2
+
+-/* The size of `size_t', as computed by sizeof. */
+-#define SIZEOF_SIZE_T 4
+-
+-/* The size of `time_t', as computed by sizeof. */
+-#define SIZEOF_TIME_T 4
+-
-/* The size of `void*', as computed by sizeof. */
-#define SIZEOF_VOIDP 4
-
/* Define to 1 if you have the ANSI C header files. */
#define STDC_HEADERS 1
+